# Drama Harvester

## Introduction

Drama Harvester is an innovative tool crafted for seamless interaction with rDrama's public APIs. It efficiently retrieves a variety of content, including comments and posts, and publishes them to Redis. This mechanism ensures not only the effective caching of data but also serves as a critical infrastructure for applications that necessitate immediate and streamlined access to the dynamic world of rDrama content.

## Features

- **Efficient Data Retrieval:** Fetches comments and posts directly from rDrama's APIs, optimized for minimal bandwidth usage.
- **Redis Integration:** Utilizes Redis for caching content, significantly enhancing data retrieval speed and reducing API call redundancy.
- **Incremental Fetching:** Employs smart fetching strategies to avoid duplicate data retrieval, ensuring that only new or updated content is processed.
- **Scheduled Fetching:** Automatically executes data retrieval operations at configured intervals, enabling up-to-date synchronization with rDrama content.
- **Graceful Shutdown:** Implements robust error handling and graceful shutdown processes, ensuring data integrity and application stability.
- **Scalable Architecture:** Designed with scalability in mind, allowing for easy horizontal scaling to accommodate growing data volumes.

## Getting Started

### Prerequisites

- Node.js (version 14 or later recommended)
- Redis server

### Installation

1. Clone the repository:
   ```bash
   git clone https://fsdfsd.net/J/DramaHarvester.git
   ```
2. Navigate to the project directory:
   ```bash
   cd DramaHarvester
   ```
3. Install the required dependencies:
   ```bash
   npm install
   ```
4. Configure environment variables by creating a `.env` file in the project root with the following content:
   ```env
   REDIS_HOST=localhost
   REDIS_PORT=6379
   #REDIS_PASSWORD=optional
   RDRAMA_API_KEY=your_rdrama_api_key_here
   ```

### Usage

To start Drama Harvester, run the following command in the project directory:
```bash
npm start
```

Drama Harvester will begin fetching content from rDrama and publishing it to Redis at regular intervals (configurable in the source code).

## Contributing

Contributions to Drama Harvester are warmly welcomed. Whether it's bug reports, feature requests, or contributions to code, we appreciate your effort to make Drama Harvester better.

To contribute:
1. Fork the repository.
2. Create a new branch for your feature (`git checkout -b feature/AmazingFeature`).
3. Commit your changes (`git commit -m 'Add some AmazingFeature'`).
4. Push to the branch (`git push origin feature/AmazingFeature`).
5. Open a Pull Request.

## License

Distributed under the MIT License. See `LICENSE` for more information.